// Import DebugServer enving and Java packages
importPackage(Packages.com.ti.debug.engine.scripting);
importPackage(Packages.com.ti.ccstudio.scripting.environment);
importPackage(Packages.java.lang);

/* Set up user variables */

var ccxml = "F2837xD.ccxml"; 			// relative to script directory, or absolute path (use forward slash '/' for absolute paths)
var cpu1Program = "main.out";			// program to load to CPU1; relative to script directory, or absolute path; Set to "" to skip loading to CPU1
var cpu2Program = "main.out";			// program to load to CPU2; relative to script directory, or absolute path; Set to "" to skip loading to CPU2
var delay1 = 2000;						// delay before connecting to device (in 2000 ms). This is to allow power supply to stabilize.
var delay2 = 100;						// delay after connect and reset, before loading program (in 100 ms). This is to let bootROM initialize the device.

/* end setting up user variables */

// script start
var env = ScriptingEnvironment.instance();
var server = env.getServer("DebugServer.1");
server.setConfig(ccxml);
var cpu1 = server.openSession(".*C28xx_CPU1");
var cpu2 = server.openSession(".*C28xx_CPU2");

// Create a log file in the current directory to log script execution
env.traceBegin("log.xml", "DefaultStylesheet.xsl");

if ( cpu1Program != "" )
{
	// delay
	env.traceWrite("\n-- Delay before connect.");
	java.lang.Thread.sleep(delay1);

	// Connect to target
	env.traceWrite("\n-- Connecting to CPU1...");
	cpu1.target.connect();
	env.traceWrite("-- Connected.");

	// reset the target
	env.traceWrite("\n-- Reset CPU1.");
	cpu1.target.reset();

	// free run/halt
	env.traceWrite("\n-- Free run, and halt before load.");
	cpu1.expression.evaluate("GEL_RunF()");
	java.lang.Thread.sleep(delay2);
	cpu1.target.halt();

	try{
		// turn on verbose
		cpu1.flash.options.setBoolean("FlashVerboseMode",true);
		
		// Load the Program
		env.traceWrite("\n-- Loading program to CPU1...");
		cpu1.memory.loadProgram(cpu1Program);
		env.traceWrite("-- Program Loaded.");
	}
	catch(err)
	{
		env.traceWrite("-- Error loading program to CPU1.");
	}
}

if ( cpu2Program != "" )
{
	// delay
	env.traceWrite("\n-- Delay before connect.");
	java.lang.Thread.sleep(delay1);

	// Connect to target
	env.traceWrite("\n-- Connecting to CPU2...");
	cpu2.target.connect();
	env.traceWrite("-- Connected.");

	// reset the target
	env.traceWrite("\n-- Reset CPU2.");
	cpu2.target.reset();

	// free run/halt
	env.traceWrite("\n-- Free run, and halt before load.");
	cpu2.expression.evaluate("GEL_RunF()");
	java.lang.Thread.sleep(delay2);
	cpu2.target.halt();

	try{
		// turn on verbose
		cpu2.flash.options.setBoolean("FlashVerboseMode",true);
		// cpu2.flash.options.setString("FlashCoreSelection","CPU2 (Slave)");
		
		// Load the Program
		env.traceWrite("\n-- Loading program to cpu2...");
		cpu2.memory.loadProgram(cpu2Program);
		env.traceWrite("-- Program Loaded.");
	}
	catch(err)
	{
		env.traceWrite("-- Error loading program to cpu2.");
	}
}

// cleanup
cpu1.terminate();
cpu2.terminate();
server.stop();
